@@ -35,6 +35,7 @@ from __future__ import print_function
 from univention.config_registry import ConfigRegistry
 
 from six.moves.configparser import ConfigParser
+from six.moves.urllib_parse import quote
 import os
 import re
 import shlex
@@ -350,8 +351,7 @@ class ShareConfiguration(object):
 			# write share conf only if we have ucr settings
 			if not share.ucr:
 				continue
-
-			share_filename = os.path.join(ShareConfiguration.SHARES_DIR, share.name + ShareConfiguration.POSTFIX)
+			share_filename = os.path.join(ShareConfiguration.SHARES_DIR, quote(share.name, safe='') + ShareConfiguration.POSTFIX)
 			with open(share_filename, "w") as fd:
 				fd.write("[" + share.name + "]\n")
 				for option in share:
